<div align="center">

[![Logo Pokémon](https://raw.githubusercontent.com/LassaInora/Tyradex/refs/heads/images/logo.png)](https://tyradex.app/)
# Tyradex for Python
[![LassaInora - Tyradex](https://img.shields.io/static/v1?label=LassaInora&message=Tyradex&color=yellow&logo=github)](https://github.com/LassaInora/Tyradex "Go to GitHub repo")
[![GitHub tag](https://img.shields.io/github/tag/LassaInora/Tyradex?include_prereleases=&sort=semver&color=orange)](https://github.com/LassaInora/Tyradex/releases/)
[![stars - Tyradex](https://img.shields.io/github/stars/LassaInora/Tyradex?style=social)](https://github.com/LassaInora/Tyradex)
[![forks - Tyradex](https://img.shields.io/github/forks/LassaInora/Tyradex?style=social)](https://github.com/LassaInora/Tyradex)

[![PyPI version](https://badge.fury.io/py/Tyradex.svg)](https://badge.fury.io/py/Tyradex)
[![Supported Versions](https://img.shields.io/pypi/pyversions/Tyradex.svg)](https://pypi.org/project/Tyradex)

___

[![Click for README - French](https://img.shields.io/badge/Click_for_README-Français-red)](README_FRENCH.md)

---

</div>

# Overview
This Python script interacts with the [Tyradex API](https://tyradex.app/) to retrieve detailed information about 
Pokémon, Generation and Pokémon types. It is designed to provide easy access to details such as Pokédex ID, generation, 
category, statistics, etc., for individual Pokémon or types. The script is organized into classes representing different 
aspects of Pokémon data and includes functions to obtain lists of all Pokémon and types.

# How to use
## Installation
- Unix/ macOS : `python3 -m pip install --upgrade Tyradex`
- Windows : `py -m pip install --upgrade Tyradex`

## Library Interface

The Tyradex library for Python offers a simple and intuitive interface for use in your various projects.  
→ [How to use the library?](https://github.com/LassaInora/Tyradex/wiki/Labrary-Interface)

## Command Line Interface

This library also has a command-line interface that returns raw JSON data from the API, retaining the cache advantage
of the Python adaptation.
→ [How to use the CLI?](https://github.com/LassaInora/Tyradex/wiki/Command-Line-Interface)

# Dependencies

This library uses dependencies

* [requests](https://requests.readthedocs.io/en/latest/) created by [Kenneth Reitz](https://github.com/kennethreitz)
* [pratik](https://github.com/LassaInora/Pratik) created by [LassaInora](https://github.com/LassaInora)

# API Reference

* The script interacts with the Tyradex API hosted at https://tyradex.app/api/v1/.
* See the [API documentation](https://tyradex.app/docs) for details on available endpoints and data structure.

# Contributors

### API created by

* [Yarkis01](https://github.com/Yarkis01)
* [Ashzuu](https://github.com/Ashzuu)

### Python adaptation by

* [LassaInora](https://github.com/LassaInora)

# Licence

This project is licensed under the [MIT License](https://github.com/LassaInora/Tyradex/blob/main/LICENSE).